@@ -34,10 +34,10 @@ if(type==1)# C-Vine
 	{
 		for(i in 1:(d-j))
 		{
-        par.out <- BiCopSelect(v[j-1,1,],v[j-1,i+1,],familyset,selectioncrit,indeptest,level)
-				w[j,i] <- par.out$family 
-        rhoMat[j,i]  <- par.out$par
-				nuMat[j,i]  <- par.out$par2
+			par.out <- BiCopSelect(v[j-1,1,],v[j-1,i+1,],familyset,selectioncrit,indeptest,level)
+			w[j,i] <- par.out$family 
+			rhoMat[j,i]  <- par.out$par
+			nuMat[j,i]  <- par.out$par2
 
 			if(j<(d-1))
 			{
@@ -51,13 +51,13 @@ else # D-Vine
     v = array(0,c(d,2*d-4,n))
 
     for(i in 1:(d-1))
-		{
-      par.out <- BiCopSelect(data[,i],data[,i+1],familyset,selectioncrit,indeptest,level)
-			w[1,i] <- par.out$family
-			rhoMat[1,i]  <- par.out$par
-			nuMat[1,i] <- par.out$par2
+	{
+		par.out <- BiCopSelect(data[,i],data[,i+1],familyset,selectioncrit,indeptest,level)
+		w[1,i] <- par.out$family
+		rhoMat[1,i]  <- par.out$par
+		nuMat[1,i] <- par.out$par2
 
-    }
+	}
     v[1,1,] = .C("Hfunc2",as.integer(w[1,1]),as.integer(n),as.double(data[,1]), as.double(data[,2]), as.double(rhoMat[1,1]),as.double(nuMat[1,1]), as.double(rep(0,n)),PACKAGE='CDVine')[[7]]
     if(d>3)
     {
@@ -72,10 +72,10 @@ else # D-Vine
     {
 		for(i in 1:(d-j))
 		{
-        par.out <- BiCopSelect(v[j-1,2*i-1,],v[j-1,2*i,],familyset,selectioncrit,indeptest,level)
-				w[j,i] <- par.out$family
-				rhoMat[j,i]  <- par.out$par
-				nuMat[j,i] <- par.out$par2
+			par.out <- BiCopSelect(v[j-1,2*i-1,],v[j-1,2*i,],familyset,selectioncrit,indeptest,level)
+			w[j,i] <- par.out$family
+			rhoMat[j,i]  <- par.out$par
+			nuMat[j,i] <- par.out$par2
 
 		}
       v[j,1,] = .C("Hfunc2",as.integer(w[j,1]),as.integer(n),as.double(v[j-1,1,]),as.double(v[j-1,2,]),as.double(rhoMat[j,1]),as.double(nuMat[j,1]),as.double(rep(0,n)),PACKAGE='CDVine')[[7]]
@@ -102,14 +102,14 @@ for(j in 1:(d-1)){
   }
 }
 
-tt = sum(fam0==2)+sum(fam0==7)+sum(fam0==8)+sum(fam0==9)
+tt = sum(fam0==2)+sum(fam0==7)+sum(fam0==8)+sum(fam0==9)+sum(fam0==10)+sum(fam0==17)+sum(fam0==18)+sum(fam0==19)+sum(fam0==20)+sum(fam0==27)+sum(fam0==28)+sum(fam0==29)+sum(fam0==30)+sum(fam0==37)+sum(fam0==38)+sum(fam0==39)+sum(fam0==40)
 nu0=rep(0,tt)
 k=1
 for(j in 1:(d-1))
     {
       for(i in 1:(d-j))
       {
-	if(w[j,i]==2 | w[j,i]==7 | w[j,i]==8 | w[j,i]==9)
+	if(w[j,i]%in%c(2,7:10,17:20,27:30,37:40))
 	{
 		nu0[k] = nuMat[j,i]
 		k = k+1
@@ -122,7 +122,7 @@ kk=1
 dd=d*(d-1)/2
 for(k in 1:dd)
 {
-	if(fam0[k]==2 || fam0[k]==7 || fam0[k]==8 || fam0[k]==9)
+	if(fam0[k]%in%c(2,7:10,17:20,27:30,37:40))
 	{
 		nu1[k]=nu0[kk]
 		kk=kk+1
