@@ -789,11 +789,11 @@ void LL(int* family, int* n, double* u, double* v, double* theta, double* nu, do
 		}
 		Free(fuc); Free(param);
   }
-  else 
+  /*else
   {
 	  Rprintf("%d\n",*family);
 	  printError("Error in LL\t:","Unknown copula family"); 
-  }
+  }*/
   //Free memory:
   Free(dat);
   //Write to output vector:
@@ -1184,7 +1184,7 @@ void copLik(int* family, int* n, double* u, double* v, double* theta, double* nu
 		Free(fuc); Free(param);
 	}
 
-  else printError("Error in copLik\t:","Unknown copula family");
+  //else printError("Error in copLik\t:","Unknown copula family");
   //Free memory:
   Free(dat);
   //Write to output vector:
