@@ -15,13 +15,12 @@
 //////////////////////////////////////////////////////////////////////////////
 // Print error text and return to R
 //////////////////////////////////////////////////////////////////////////////
-void printError(char *text, char filename[200])
+/*void printError(char *text, char filename[200])
 {
   Rprintf(text);
   Rprintf(": %s ", filename);
   Rprintf(" !!!\n");
-  exit(0);
-}
+}*/
 
 //////////////////////////////////////////////////////////////////////////////
 // Compute gamma division in a more stable way than gamma(x1)/gamma(x2)
